@@ -447,10 +447,16 @@ impl<C: Connector> Conn<'_, C> {
     }
 
     pub(crate) fn response_content_length(&self) -> Option<u64> {
-        ContentLength::from_headers(&self.response_headers)
-            .ok()
-            .flatten()
-            .map(|cl| cl.len())
+        if self.method == Method::Head {
+            Some(0)
+        } else if let Some(StatusCode::NoContent | StatusCode::NotModified) = self.status {
+            Some(0)
+        } else {
+            ContentLength::from_headers(&self.response_headers)
+                .ok()
+                .flatten()
+                .map(|cl| cl.len())
+        }
     }
 
     /**
@@ -544,7 +550,7 @@ impl<C: Connector> Conn<'_, C> {
         if let Some(pool) = &self.pool {
             for mut candidate in pool.candidates(&socket_addrs) {
                 if poll_once(candidate.read(&mut byte)).await.is_none()
-                    && candidate.write_all(&head).await.is_ok()
+                    && candidate.write_all(head).await.is_ok()
                 {
                     return Some(candidate);
                 }
